@@ -1,8 +1,21 @@
-################################################################################
-# Strip out the samples associated with the current mixture
-#
-indy.mixture.isotope.mvn.sample = function (isotope.mvn.sample, i.mixture, n.mixtures, n.sources, n.isotopes)
+indy.mixture.isotope.mvn.sample <-
+function# Strip out the samples associated with the current mixture
+### internal function for sisus
+(isotope.mvn.sample
+### internal variable
+, i.mixture
+### internal variable
+, n.mixtures
+### internal variable
+, n.sources
+### internal variable
+, n.isotopes
+### internal variable
+)
 {
+  ##details<<
+  ## interal function for sisus.run()
+
   # indicies for the i.mixture mvn samples and the isotope mvn samples
   ind.mixture.begin = (i.mixture-1)*n.isotopes+1;
   ind.mixture.end   = (i.mixture)*n.isotopes;
@@ -13,4 +26,5 @@ indy.mixture.isotope.mvn.sample = function (isotope.mvn.sample, i.mixture, n.mix
 
   return(isotope.mvn.sample.indy.mixture);
 
-} # indy.mixture.isotope.mvn.sample()
+  ### internal variable
+}
