@@ -1,8 +1,20 @@
-################################################################################
-# Resamples weighted samples from the polytope from the Dirichlet distribution on the p vector
-resample.dirichlet.p = function (M.re, sam.re, alpha.p.dirichlet, n.vertices)
+resample.dirichlet.p <-
+function# Resamples weighted samples from the polytope from the Dirichlet distribution on the p vector
+### internal function for sisus
+(M.re
+### internal variable
+, sam.re
+### internal variable
+, alpha.p.dirichlet
+### internal variable
+, n.vertices
+### internal variable
+)
 {
-  library("gtools");
+  ##details<<
+  ## interal function for sisus.run()
+
+  # attached via DESCRIPTION # library("gtools");
   # Dirichlet resampling of p-vectors
   # Weights
   weights.p.dirichlet.temp = ddirichlet(sam.re[(n.vertices+1):M.re,], alpha.p.dirichlet);             # evaluate dirichlet probabilities
@@ -12,4 +24,5 @@ resample.dirichlet.p = function (M.re, sam.re, alpha.p.dirichlet, n.vertices)
   resam = rbind(sam.re[1:n.vertices,], sam.re[resample.ind,]);                                        # update sampling with resample, putting vertices at beginning of sample
   if (M.re==1) {resam = t(as.matrix(resam));}                                                         # if single solution, still make a matrix
   return(resam);                                                                                      # return resample
-} # resample.dirichlet.p()
+  ### internal variable
+}
